@@ -1,3 +1,3 @@
 estfun.ssym <-
-function(object){
+function(object, ...){
 list(mu=object$score.mu, phi=object$score.phi)}
